.map-wrapper{height:100vh;width:100%;overflow-y:hidden}#viewDiv{height:100%;width:100%}.json-viewer-portal{max-height:685px}#app{font-family:Avenir,Helvetica,Arial,sans-serif;-webkit-font-smoothing:antialiased;-moz-osx-font-smoothing:grayscale;color:#2c3e50}.fa-btn{cursor:pointer;font-size:1.5rem}.bmi-green{color:#006938}.fa-btn:hover{cursor:pointer;transform:scale(1.3)!important;-webkit-transform:scale(1.3)!important;-moz-transform:scale(1.3)!important}